@@ -1,7 +1,7 @@
 /*
  *
  * This file is part of the iText (R) project.
-    Copyright (c) 1998-2017 iText Group NV
+    Copyright (c) 1998-2019 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -732,7 +732,7 @@ public class BarcodeDatamatrix {
                     for (i = unlatch + 1; i < dataOffset; i++) {
                         if (data[i] == EXTENDED_ASCII)
                             i++;
-                        if (data[i] >= -127 && data[i] <= -27)
+                        if (data[i] >= (byte) 129 && data[i] <= (byte) 229)
                             amountOfEncodedWithASCII++;
                         amountOfEncodedWithASCII++;
                     }
