@@ -1,7 +1,7 @@
 /*
  *
  * This file is part of the iText (R) project.
-    Copyright (c) 1998-2017 iText Group NV
+    Copyright (c) 1998-2019 iText Group NV
  * Authors: Kevin Day, Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -354,20 +354,17 @@ public class LocationTextExtractionStrategy implements TextExtractionStrategy {
         }
         
         public boolean isAtWordBoundary(TextChunkLocation previous){
-            /**
-             * Here we handle a very specific case which in PDF may look like:
-             * -.232 Tc [( P)-226.2(r)-231.8(e)-230.8(f)-238(a)-238.9(c)-228.9(e)]TJ
-             * The font's charSpace width is 0.232 and it's compensated with charSpacing of 0.232.
-             * And a resultant TextChunk.charSpaceWidth comes to TextChunk constructor as 0.
-             * In this case every chunk is considered as a word boundary and space is added.
-             * We should consider charSpaceWidth equal (or close) to zero as a no-space.
-             */
-            if (getCharSpaceWidth() < 0.1f)
-                return false;
-
             float dist = distanceFromEndOf(previous);
 
-            return dist < -getCharSpaceWidth() || dist > getCharSpaceWidth()/2.0f;
+            if (dist < 0) {
+                dist = previous.distanceFromEndOf(this);
+
+                //The situation when the chunks intersect. We don't need to add space in this case
+                if (dist < 0) {
+                    return false;
+                }
+            }
+            return dist > getCharSpaceWidth() / 2.0f;
         }
 
         public int compareTo(TextChunkLocation other) {
